@@ -2,13 +2,7 @@ import uuid
 
 from django.contrib import admin
 from django.contrib.admin.options import InlineModelAdmin
-
-JQUERY_JS = "admin/js/vendor/jquery/jquery.js"
-JQUERY_INIT_JS = "admin/js/jquery.init.js"
-
-def jquery_plugins(jslist):
-    return [JQUERY_JS] + jslist + [JQUERY_INIT_JS]
-
+from .utils import jquery_plugins
 
 class UuidFieldSearchableAdmin(admin.ModelAdmin):
     """Enable search by uuid string with dashes.
@@ -38,3 +32,15 @@ class InlineBooleanFieldsAllowOnlyOneCheckedMixin(InlineModelAdmin):
             "django-jquery-plugins/jquery.utils.js",
             "django-jquery-plugins/inline-boolean-fields-allow-only-one-checked.js",
         ])
+
+
+class WithInlineUniqueChoiceFieldsMixin(InlineModelAdmin):
+
+    special_class_name = "with-inline-unique-choice-fields"
+    field_name_prefix = special_class_name + "-"
+
+    class Media:
+        js = jquery_plugins([
+            "django-jquery-plugins/jquery.utils.js",
+            "django-jquery-plugins/with-inline-unique-choice-fields.js",
+        ])
